@@ -14,20 +14,17 @@
  * limitations under the License.
  */
 
-/******************************************************************************
-globus_common.c
+#ifndef GLOBUS_DONT_DOCUMENT_INTERNAL
 
-Description:
-
-  Routines common to all of Globus
-
-CVS Information:
-
-******************************************************************************/
+/**
+ * @file globus_thread_common.c
+ * @brief Thread Model-Indepent Functions
+ */
 
 /******************************************************************************
 			     Include header files
 ******************************************************************************/
+#include "globus_i_common_config.h"
 #include "globus_common_include.h"
 #include "globus_thread_common.h"
 #include "globus_i_thread.h"
@@ -479,4 +476,4 @@ globus_i_thread_ignore_sigpipe(void)
 
 #endif
 
-
+#endif /* GLOBUS_DONT_DOCUMENT_INTERNAL */
