@@ -14,24 +14,17 @@
  * limitations under the License.
  */
 
-/******************************************************************************
-globus_thread_windows.c
+#ifndef GLOBUS_DONT_DOCUMENT_INTERNAL
 
-Description:
-
-  Bindings for the Globus threads package, to be used when Globus has been
-  configured to use Windows.
-
-CVS Information:
-
-  $Source: /home/globdev/CVS/globus-packages/common/source/library/globus_thread_windows.c,v $
-  $Date: 2010/05/17 14:58:45 $
-  $Revision: 1.8 $
-  $State: Exp $
-  $Author: bester $
-******************************************************************************/
+/**
+ * @file globus_thread_windows.c
+ * @brief Windows Threads Bindings
+ */
 
+#include "globus_i_common_config.h"
+#include "globus_thread.h"
 #include "globus_common_include.h"
+#include <windows.h>
 #include "globus_thread_common.h"
 #include "globus_i_thread.h"
 #include "globus_libc.h"
@@ -123,8 +116,7 @@ globus_l_winthread_deactivate(void)
 }
 /* globus_l_thread_deactivate() */
 
-globus_module_descriptor_t
-globus_extension_module =
+GlobusExtensionDefineModule(globus_thread_windows) =
 {
     "globus_thread_windows",
     globus_l_winthread_activate,
@@ -1029,3 +1021,4 @@ globus_l_winthread_get_impl(void)
     return &globus_l_winthread_impl;
 }
 
+#endif /* GLOBUS_DONT_DOCUMENT_INTERNAL */
